summaryrefslogtreecommitdiffstats
path: root/src/usr/isteps
diff options
context:
space:
mode:
authorDan Crowell <dcrowell@us.ibm.com>2015-12-14 09:30:28 -0600
committerDaniel M. Crowell <dcrowell@us.ibm.com>2016-02-29 16:29:48 -0500
commitbee7f1cbcd5bf18acc539c9c9b6a14960dadea3d (patch)
tree2b7f1c777e10bc41101d7515e96122b3fd8cd1dc /src/usr/isteps
parent1fe31da7eeae17f43b6908f9eccf30d6a8b355dd (diff)
downloadtalos-hostboot-bee7f1cbcd5bf18acc539c9c9b6a14960dadea3d.tar.gz
talos-hostboot-bee7f1cbcd5bf18acc539c9c9b6a14960dadea3d.zip
Update constants and comments for P9 PIR format
Implemented a set of macros and constants that can be used everywhere to translate a PIR into its component parts and pull out individual pieces of data from a complete PIR. Also added and updated the references to the old ATTR_FABRIC_NODE_ID with ATTR_FABRIC_GROUP_ID. Change-Id: If9735f53940e5849a648729e4bf8ca0cfbb09f6e RTC: 88055 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/706 Tested-by: Jenkins Server Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/usr/isteps')
-rw-r--r--src/usr/isteps/istep10/call_proc_build_smp.C6
-rw-r--r--src/usr/isteps/istep14/call_proc_exit_cache_contained.C8
-rw-r--r--src/usr/isteps/istep16/call_host_activate_slave_cores.C10
-rw-r--r--src/usr/isteps/istep21/call_host_start_payload.C8
4 files changed, 15 insertions, 17 deletions
diff --git a/src/usr/isteps/istep10/call_proc_build_smp.C b/src/usr/isteps/istep10/call_proc_build_smp.C
index 24323255d..0d3cf18b2 100644
--- a/src/usr/isteps/istep10/call_proc_build_smp.C
+++ b/src/usr/isteps/istep10/call_proc_build_smp.C
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2015 */
+/* Contributors Listed Below - COPYRIGHT 2015,2016 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -159,9 +159,9 @@ void* call_proc_build_smp (void *io_pArgs)
(const_cast<TARGETING::Target*>(l_itr->second)));
l_procEntry.f0_node_id = static_cast<proc_fab_smp_node_id>(
- l_pTarget->getAttr<TARGETING::ATTR_FABRIC_NODE_ID>());
+ l_pTarget->getAttr<TARGETING::ATTR_FABRIC_GROUP_ID>());
l_procEntry.f1_node_id = static_cast<proc_fab_smp_node_id>(
- l_pParent->getAttr<TARGETING::ATTR_FABRIC_NODE_ID>());
+ l_pParent->getAttr<TARGETING::ATTR_FABRIC_GROUP_ID>());
}
// Get X-BUS
diff --git a/src/usr/isteps/istep16/call_host_activate_slave_cores.C b/src/usr/isteps/istep16/call_host_activate_slave_cores.C
index 88e8f025e..ebb51482c 100644
--- a/src/usr/isteps/istep16/call_host_activate_slave_cores.C
+++ b/src/usr/isteps/istep16/call_host_activate_slave_cores.C
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2015 */
+/* Contributors Listed Below - COPYRIGHT 2015,2016 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -38,7 +38,7 @@
#include <isteps/hwpisteperror.H>
#include <errl/errludtarget.H>
-#include <intr/interrupt.H>
+#include <arch/pirformat.H>
#include <console/consoleif.H>
// targeting support
@@ -88,8 +88,8 @@ void* call_host_activate_slave_cores (void *io_pArgs)
CHIP_UNIT_ATTR l_coreId =
(*l_core)->getAttr<TARGETING::ATTR_CHIP_UNIT>();
- FABRIC_NODE_ID_ATTR l_logicalNodeId =
- l_processor->getAttr<TARGETING::ATTR_FABRIC_NODE_ID>();
+ FABRIC_GROUP_ID_ATTR l_logicalNodeId =
+ l_processor->getAttr<TARGETING::ATTR_FABRIC_GROUP_ID>();
FABRIC_CHIP_ID_ATTR l_chipId =
l_processor->getAttr<TARGETING::ATTR_FABRIC_CHIP_ID>();
TARGETING::Target* sys = NULL;
@@ -97,7 +97,7 @@ void* call_host_activate_slave_cores (void *io_pArgs)
assert( sys != NULL );
uint64_t en_threads = sys->getAttr<ATTR_ENABLED_THREADS>();
- uint64_t pir = INTR::PIR_t(l_logicalNodeId, l_chipId, l_coreId).word;
+ uint64_t pir = PIR_t(l_logicalNodeId, l_chipId, l_coreId).word;
if (pir != l_masterCoreID)
{
diff --git a/src/usr/isteps/istep14/call_proc_exit_cache_contained.C b/src/usr/isteps/istep14/call_proc_exit_cache_contained.C
index d517b6979..a3a11e59e 100644
--- a/src/usr/isteps/istep14/call_proc_exit_cache_contained.C
+++ b/src/usr/isteps/istep14/call_proc_exit_cache_contained.C
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2015 */
+/* Contributors Listed Below - COPYRIGHT 2015,2016 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -36,7 +36,7 @@
#include <targeting/common/utilFilter.H>
#include <sys/mm.h>
-#include <intr/interrupt.H>
+#include <arch/pirformat.H>
#include <isteps/hwpf_reasoncodes.H>
// @TODO RTC:134082 remove below block
@@ -103,11 +103,11 @@ void* call_proc_exit_cache_contained (void *io_pArgs)
l_sys->getAttr<TARGETING::ATTR_MIRROR_BASE_ADDRESS>();
// For single-node systems, the non-master processors can be
// in a different logical (powerbus) node.
// Need to migrate task to master.
task_affinity_pin();
task_affinity_migrate_to_master();
- uint64_t this_node = INTR::PIR_t(task_getcpuid()).nodeId;
+ uint64_t this_node = PIR_t(task_getcpuid()).groupId;
task_affinity_unpin();
l_mirrorBaseAddr += (this_node * hrmor_base)/2;
@@ -103,11 +103,11 @@ void* call_proc_exit_cache_contained (void *io_pArgs)
l_sys->getAttr<TARGETING::ATTR_MIRROR_BASE_ADDRESS>();
// For single-node systems, the non-master processors can be
- // in a different logical (powerbus) node.
+ // in a different logical (powerbus) group.
// Need to migrate task to master.
task_affinity_pin();
diff --git a/src/usr/isteps/istep21/call_host_start_payload.C b/src/usr/isteps/istep21/call_host_start_payload.C
index f3760ede6..a57ccd01b 100644
--- a/src/usr/isteps/istep21/call_host_start_payload.C
+++ b/src/usr/isteps/istep21/call_host_start_payload.C
@@ -31,7 +31,6 @@
#include <initservice/initserviceif.H>
#include <initservice/istepdispatcherif.H>
#include <sys/task.h>
-#include <intr/interrupt.H>
#include <initservice/extinitserviceif.H>
#include <hbotcompid.H>
#include <sys/misc.h>
@@ -43,9 +42,8 @@
#include <devtree/devtreeif.H>
#include <kernel/ipc.H> // for internode data areas
#include <mbox/ipc_msg_types.H>
-
#include <devicefw/userif.H>
-
+#include <arch/pirformat.H>
@@ -195,11 +193,11 @@ void* call_host_start_payload (void *io_pArgs)
"call_host_start_payload entry" );
// For single-node systems, the non-master processors can be in a
// different logical (powerbus) node. Need to migrate task to master.
task_affinity_pin();
task_affinity_migrate_to_master();
- uint64_t this_node = INTR::PIR_t(task_getcpuid()).nodeId;
+ uint64_t this_node = PIR_t(task_getcpuid()).groupId;
task_affinity_unpin();
OpenPOWER on IntegriCloud
@@ -195,11 +193,11 @@ void* call_host_start_payload (void *io_pArgs)
"call_host_start_payload entry" );
// For single-node systems, the non-master processors can be in a
- // different logical (powerbus) node. Need to migrate task to master.
+ // different logical (powerbus) group. Need to migrate task to master.
task_affinity_pin();
task_affinity_migrate_to_master();